using Siger.Middlelayer.Repository.Request;
using System;
using System.Collections.Generic;
using System.Text;

namespace Siger.Middlelayer.DashboardRepository.Request
{
    public class RequestCustomerCountByMonth
    {
        /// <summary>
        /// 数量
        /// </summary>
        public int quantity { get; set; }

        /// <summary>
        /// 月份
        /// </summary>
        public int month { get; set; }
    }

    public class RequestCustomerSituation
    {
        /// <summary>
        /// 数量
        /// </summary>
        public int quantity { get; set; }

        /// <summary>
        /// 客户名称
        /// </summary>
        public string customer_name { get; set; }
        /// <summary>
        /// 地址
        /// </summary>
        public string address { get; set; }
        /// <summary>
        /// 省
        /// </summary>
        public string province { get; set; }
        /// <summary>
        /// 市
        /// </summary>
        public string city { get; set; }
        /// <summary>
        /// 区
        /// </summary>
        public string area { get; set; }
    }
    
    public class RequestCoordinate
    {
         /// <summary>
        /// 市
        /// </summary>
        public string city { get; set; }
        /// <summary>
        /// 经度
        /// </summary>
        public string longitude { get; set; }
        /// <summary>
        /// 纬度
        /// </summary>
        public string latitude { get; set; }
    }
    public class RequestCustomerAddress
    {
        /// <summary>
        /// 数量
        /// </summary>
        public int quantity { get; set; }

        /// <summary>
        /// 地址
        /// </summary>
        public string address { get; set; }
        /// <summary>
        /// 省
        /// </summary>
        public string province { get; set; }
    }
    public class RequestUpdate: RequestAddress
    {
        public int id { get; set; }
    }

    public class RequestSelect : RequestPageBase
    {
        /// <summary>
        /// 客户名称
        /// </summary>
        public string customer_name { get; set; }
        public string startTime { get; set; }
        public string endTime { get; set; }

    }
    public class RequestAddress
    {
        /// <summary>
        /// 客户名称
        /// </summary>
        public string customer_name { get; set; }
        /// <summary>
        /// 设备数量
        /// </summary>
        public int machine_quantity { get; set; }
        /// <summary>
        ///用户数量
        /// </summary>
        public int quantity { get; set; }
        /// <summary>
        /// 省
        /// </summary>
        public string province { get; set; }
        /// <summary>
        /// 市
        /// </summary>
        public string city { get; set; }
        /// <summary>
        /// 区
        /// </summary>
        public string area { get; set; }
        /// <summary>
        /// 用户地址
        /// </summary>
        public string address { get; set; }
        /// <summary>
        /// 经度
        /// </summary>
        public string longitude { get; set; }
        /// <summary>
        /// 纬度
        /// </summary>
        public string latitude { get; set; }
        /// <summary>
        /// 签约时间
        /// </summary>
        public string signing_time { get; set; }
    }

    public class RequestAllNum
    {
        /// <summary>
        /// 设备数量
        /// </summary>
        public int machine_quantity { get; set; }

        /// <summary>
        /// 客户数量
        /// </summary>
        public int customer_quantity { get; set; }

        /// <summary>
        /// 用户数量
        /// </summary>
        public int user_quantity { get; set; }
    }
}
